# Change Log

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/).

## [0.1.3] — 2024-11-10
### Fixed
- Fix deprecation of `pandas.np`, h/t @simon-smart88. ([#9](https://github.com/jsvine/weightedcalcs/issues/9))
- Fix deprecation of `DataFrameGroupBy.apply operated on the grouping columns`.

### Changed
- Change minimum `pandas` version to `2.0`.

## [0.1.2] — 2017-06-17
### Fixed
- Fix incompatibility with pandas 0.20.1

## [0.1.1] — 2017-04-08
### Added
- MANIFEST.in

## [0.1.0] — 2017-03-30
### Added
- Support for Python 2.7
- Support for non-pandas input
- Full test coverage

## [0.0.0] — 2016-12-23

Initial release
